@@ -136,13 +136,13 @@ static GtkRadioActionEntry radio_entries[] = {
 
 static GtkRadioActionEntry smart_home_end_entries[] = {
 	{ "SmartHomeEndDisabled", NULL, "Disabled", NULL,
-	  "Smart Home/End disabled", GTKSOURCEVIEW_SMART_HOME_END_DISABLED },
+	  "Smart Home/End disabled", GTK_SOURCE_SMART_HOME_END_DISABLED },
 	{ "SmartHomeEndBefore", NULL, "Before", NULL,
-	  "Smart Home/End before", GTKSOURCEVIEW_SMART_HOME_END_BEFORE },
+	  "Smart Home/End before", GTK_SOURCE_SMART_HOME_END_BEFORE },
 	{ "SmartHomeEndAfter", NULL, "After", NULL,
-	  "Smart Home/End after", GTKSOURCEVIEW_SMART_HOME_END_AFTER },
+	  "Smart Home/End after", GTK_SOURCE_SMART_HOME_END_AFTER },
 	{ "SmartHomeEndAlways", NULL, "Always", NULL,
-	  "Smart Home/End always", GTKSOURCEVIEW_SMART_HOME_END_ALWAYS }
+	  "Smart Home/End always", GTK_SOURCE_SMART_HOME_END_ALWAYS }
 };
 
 static const gchar *view_ui_description =
@@ -284,7 +284,7 @@ remove_all_markers (GtkSourceBuffer *buffer)
 static GtkSourceLanguage *
 get_language_for_filename (const gchar *filename)
 {
-	const GSList *list;
+	GSList *list;
 	gchar *filename_utf8;
 	GtkSourceLanguageManager *manager;
 
@@ -292,7 +292,7 @@ get_language_for_filename (const gchar *filename)
 	g_return_val_if_fail (filename_utf8 != NULL, NULL);
 
 	manager = gtk_source_language_manager_get_default ();
-	list = gtk_source_language_manager_get_available_languages (manager);
+	list = gtk_source_language_manager_list_languages (manager);
 
 	while (list != NULL)
 	{
@@ -300,7 +300,7 @@ get_language_for_filename (const gchar *filename)
 		gchar **globs, **p;
 
 		lang = list->data;
-		list = list->next;
+		list = g_slist_delete_link (list, list);
 
 		globs = gtk_source_language_get_globs (lang);
 		if (globs == NULL)
@@ -312,6 +312,7 @@ get_language_for_filename (const gchar *filename)
 			{
 				g_strfreev (globs);
 				g_free (filename_utf8);
+				g_slist_free (list);
 				return lang;
 			}
 		}
@@ -329,11 +330,11 @@ get_language_for_filename (const gchar *filename)
 static GtkSourceLanguage *
 get_language_for_mime_type (const gchar *mime)
 {
-	const GSList *list;
+	GSList *list;
 	GtkSourceLanguageManager *manager;
 
 	manager = gtk_source_language_manager_get_default ();
-	list = gtk_source_language_manager_get_available_languages (manager);
+	list = gtk_source_language_manager_list_languages (manager);
 
 	while (list != NULL)
 	{
@@ -341,7 +342,7 @@ get_language_for_mime_type (const gchar *mime)
 		gchar **mimetypes, **p;
 
 		lang = list->data;
-		list = list->next;
+		list = g_slist_delete_link (list, list);
 
 		mimetypes = gtk_source_language_get_mime_types (lang);
 
@@ -353,6 +354,7 @@ get_language_for_mime_type (const gchar *mime)
 			if (strcmp (*p, mime) == 0)
 			{
 				g_strfreev (mimetypes);
+				g_slist_free (list);
 				return lang;
 			}
 		}
@@ -406,7 +408,7 @@ open_file (GtkSourceBuffer *buffer, const gchar *filename)
 	GtkSourceLanguage *language = NULL;
 	gchar *freeme = NULL;
 	gboolean success = FALSE;
-
+		
 	if (!g_path_is_absolute (filename))
 	{
 		gchar *curdir = g_get_current_dir ();
@@ -432,7 +434,37 @@ open_file (GtkSourceBuffer *buffer, const gchar *filename)
 				"filename", g_strdup (filename),
 				(GDestroyNotify) g_free);
 
+	if (language != NULL)
+	{
+		gchar **styles;
+		
+		styles = gtk_source_language_get_style_ids (language);
+		
+		if (styles == NULL)
+			g_print ("No styles in language '%s'\n", gtk_source_language_get_name (language));
+		else 
+		{
+			gchar **ids;
+			g_print ("Styles in in language '%s':\n", gtk_source_language_get_name (language));
+			
+			ids = styles;
+			
+			while (*ids != NULL) 
+			{
+				const gchar *name;
+				
+				name = gtk_source_language_get_style_name (language, *ids);
 
+				g_print ("- %s (name: '%s')\n", *ids, name);
+
+				++ids;
+			}
+			
+			g_strfreev (styles);		
+		}	
+		
+		g_print("\n");
+	}
 out:
 	g_free (freeme);
 	return success;
@@ -1155,7 +1187,9 @@ main (int argc, char *argv[])
 	GtkSourceBuffer *buffer;
 
 	gchar *builtin_lang_dirs[] = {TOP_SRCDIR "/gtksourceview/language-specs", NULL};
+	gchar *builtin_sm_dirs[] = {TOP_SRCDIR "/gtksourceview/language-specs", NULL};
 	gchar **lang_dirs;
+	const gchar * const * schemes;
 	gboolean use_default_paths = FALSE;
 
 	gchar *style_scheme_id = NULL;
@@ -1188,11 +1222,35 @@ main (int argc, char *argv[])
 	lang_dirs = use_default_paths ? NULL : builtin_lang_dirs;
 	lm = gtk_source_language_manager_get_default ();
 	gtk_source_language_manager_set_search_path (lm, lang_dirs);
+
+	lang_dirs = use_default_paths ? NULL : builtin_sm_dirs;
+
 	sm = gtk_source_style_manager_get_default ();
 	gtk_source_style_manager_set_search_path (sm, lang_dirs);
 
+	if (!use_default_paths)
+		gtk_source_style_manager_append_search_path (sm, TOP_SRCDIR "/tests/test-scheme.xml");
+
+	schemes = gtk_source_style_manager_get_scheme_ids (sm);
+	g_print ("Available style schemes:\n");
+	while (*schemes != NULL)
+	{
+		style_scheme = gtk_source_style_manager_get_scheme (sm, *schemes);
+
+		g_print (" - [%s] %s: %s\n",
+			 gtk_source_style_scheme_get_id (style_scheme),
+			 gtk_source_style_scheme_get_name (style_scheme),
+			 gtk_source_style_scheme_get_description (style_scheme) ?
+				gtk_source_style_scheme_get_description (style_scheme) : "");
+
+		++schemes;
+	}
+	g_print("\n");
+
 	if (style_scheme_id != NULL)
 		style_scheme = gtk_source_style_manager_get_scheme (sm, style_scheme_id);
+	else
+		style_scheme = NULL;
 
 	/* create buffer */
 	buffer = gtk_source_buffer_new (NULL);
